@@ -12,7 +12,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -21,12 +21,11 @@
 static void
 test_valid (void)
 {
-  ManetteMappingManager *mapping_manager;
+  g_autoptr (ManetteMappingManager) mapping_manager = NULL;
 
   mapping_manager = manette_mapping_manager_new ();
   g_assert_nonnull (mapping_manager);
   g_assert_true (MANETTE_IS_MAPPING_MANAGER (mapping_manager));
-  g_object_unref (mapping_manager);
 }
 
 int
